from .T2I import T2I


class DreamShaper(T2I):
    def __init__(self, api_key=None):
        super().__init__(
            url="https://api.segmind.com/v1/sd1.5-dreamshaper", api_key=api_key
        )

    def generate(
        self,
        prompt: str,
        negative_prompt: str = "cartoon, 3d, sketches, (painting by bad-artist), (worst quality:2), (low quality:2), (normal quality:2), lowres, normal quality, bad anatomy, (bad-hands-5), (badhandv4), fat, curvy, thick, dull, simple background, ugly, mole, skin tags, acne, freckles, lightning. veil, hat, hood, ((blurry)), ((monochrome)), ((from side)), ((back turned)), Far away, back turned,",
        samples=1,
        scheduler="dpmpp_2m",
        num_inference_steps=20,
        guidance_scale=7,
        seed=None,
        strength=0.75,
    ):
        return super().generate(
            prompt=prompt,
            negative_prompt=negative_prompt,
            samples=samples,
            scheduler=scheduler,
            num_inference_steps=num_inference_steps,
            guidance_scale=guidance_scale,
            seed=seed,
            strength=strength,
        )



"""
import requests


api_key = "YOUR API-KEY"
url = "https://api.segmind.com/v1/sd1.5-deepspacediffusion"

# Request payload
data = {
  "prompt": "jwst, nebula, spiral galaxy,mixed colors,outerspace, hyper quality, intricate detail, ultra realistic, maximum detail, foreground focus, instagram, 8k, volumetric light, cinematic, octane render, uplight, no blur, 8k",
  "negative_prompt": "ng_deepnegative_v1_75t,badhandv4, (worst quality:2), (low quality:2), (normal quality:2), lowres,watermark, single color, monochrome",
  "scheduler": "dpmpp_2m",
  "num_inference_steps": 30,
  "guidance_scale": 7,
  "samples": 1,
  "seed": 720692329,
  "img_width": 512,
  "img_height": 768
}

response = requests.post(url, json=data, headers={'x-api-key': api_key})
print(response)

"""

from .T2I import T2I


class DeepSpaceDiffusion(T2I):
    def __init__(self, api_key=None):
        super().__init__(
            url="https://api.segmind.com/v1/sd1.5-deepspacediffusion", api_key=api_key
        )

    def generate(
        self,
        prompt: str,
        negative_prompt: str = "ng_deepnegative_v1_75t,badhandv4, (worst quality:2), (low quality:2), (normal quality:2), lowres,watermark, single color, monochrome",
        samples=1,
        scheduler="dpmpp_2m",
        num_inference_steps=30,
        guidance_scale=7,
        seed=None,
        strength=0.75,
    ):
        return super().generate(
            prompt=prompt,
            negative_prompt=negative_prompt,
            samples=samples,
            scheduler=scheduler,
            num_inference_steps=num_inference_steps,
            guidance_scale=guidance_scale,
            seed=seed,
            strength=strength,
        )



import requests
from PIL import Image
from io import BytesIO
from .utils import toB64

class SAM:
    """
    This API allows you to generate Segmentation Masks using SAM (Segment Anything Model) and is available at https://api.segmind.com/v1/sam-img2mask.

    The API accepts the following parameters:
        imageUrl: The URL of the image to be processed.

        The API returns the following:
            PIL Image of the segmentation mask of the image.

    It also prints the number of credits remaining in your account.
    """

    def __init__(self, api_key: str = None):
        self.url = "https://api.segmind.com/v1/sam-img2img"
        self.headers = {"x-api-key": f"{api_key}"}
        if api_key is None:
            raise Exception("API Key is required")
    
    def generate(self, imageUrl : str):
        data = {
        "image": toB64(imageUrl)
    }
        response = requests.post(self.url, json = data, headers = self.headers)
        if response.status_code == 200:
            print(
                f"Success! You have {response.headers['X-remaining-credits']} credits remaining"
            )
            return Image.open(BytesIO(response.content))
        else:
            raise Exception(f"Error: {response.status_code}")



from .T2I import T2I


class TinySD(T2I):
    def __init__(self, api_key=None):
        super().__init__(
            url="https://api.segmind.com/v1/tinysd1.5-txt2img", api_key=api_key
        )

    def generate(
        self,
        prompt: str,
        negative_prompt: str = "(deformed iris, deformed pupils, semi-realistic, cgi, render, sketch, cartoon, drawing, anime), text, cropped, out of frame, worst quality, low quality, jpeg artifacts, ugly, duplicate, morbid, mutilated, extra fingers, mutated hands, poorly drawn hands, poorly drawn face, mutation, deformed, blurry, dehydrated, bad anatomy, bad proportions, extra limbs, cloned face, disfigured, gross proportions, malformed limbs, missing arms, missing legs, extra arms, extra legs, fused fingers, too many fingers, long neck, BadDream, UnrealisticDream",
        samples=1,
        scheduler="dmpp_2m",
        num_inference_steps=25,
        guidance_scale=7,
        seed=None,
        strength=0.75,
    ):
        return super().generate(
            prompt=prompt,
            negative_prompt=negative_prompt,
            samples=samples,
            scheduler=scheduler,
            num_inference_steps=num_inference_steps,
            guidance_scale=guidance_scale,
            seed=seed,
            strength=strength,
        )



from .T2I import T2I


class PortraitSD(T2I):
    def __init__(self, api_key=None):
        super().__init__(
            url="https://api.segmind.com/v1/potraitsd1.5-txt2img", api_key=api_key
        )

    def generate(
        self,
        prompt: str,
        negative_prompt: str = "(deformed iris, deformed pupils, semi-realistic, cgi, render, sketch, cartoon, drawing, anime), text, cropped, out of frame, worst quality, low quality, ugly, tiling, poorly drawn hands, poorly drawn feet, poorly drawn face, out of frame, extra limbs, disfigured, deformed, body out of frame, blurry, bad anatomy, blurred, watermark, grainy, signature, cut off, draft, jpeg artifacts, ugly, duplicate, morbid, mutilated, extra fingers, mutated hands, poorly drawn hands, poorly drawn face, mutation, deformed, blurry, dehydrated, bad anatomy, bad proportions, extra limbs, cloned face, disfigured, gross proportions, malformed limbs, missing arms, missing legs, extra arms, extra legs, fused fingers, too many fingers, long neck, BadDream, UnrealisticDream",
        samples=1,
        scheduler="dpmpp_2m",
        num_inference_steps=25,
        guidance_scale=7,
        seed=None,
        strength=0.75,
    ):
        return super().generate(
            prompt=prompt,
            negative_prompt=negative_prompt,
            samples=samples,
            scheduler=scheduler,
            num_inference_steps=num_inference_steps,
            guidance_scale=guidance_scale,
            seed=seed,
            strength=strength,
        )



from PIL import Image
import requests
from io import BytesIO
from .utils import toB64


class Word2Img:
    """
    This API allows you to transform text descriptions into corresponding image representations and is available at https://api.segmind.com/v1/w2imgsd1.5-img2img.

    The API accepts the following parameters:
        image: The link to the image to be used as the base image.
        prompt: The text description of the image to be generated.
        negative_prompt: The text description of the image to be avoided.
        scheduler: The scheduler to be used for the generation. The default value is DDIM.
        num_inference_steps: The number of inference steps to be used for the generation. The default value is 20.
        guidance_scale: The guidance scale to be used for the generation. The default value is 7.5.
        control_scale: The control scale to be used for the generation. The default value is 1.9.
        control_start: The control start to be used for the generation. The default value is 0.19.
        control_end: The control end to be used for the generation. The default value is 1.
        samples: The number of images to be generated. The default value is 1.
        seed: The seed to be used for the generation. The default value is 1234567.
        size: The size of the image to be generated. The default value is 768.
        base64: The base64 to be used for the generation. The default value is False.

    The API returns the following:
        The generated image.

    It also prints the number of credits remaining in your account.
    """

    def __init__(self, api_key=None):
        self.url = "https://api.segmind.com/v1/w2imgsd1.5-img2img"
        self.headers = {"x-api-key": f"{api_key}"}
        if api_key is None:
            raise Exception("API Key is required")

    def generate(
        self,
        image,
        prompt,
        negative_prompt="None",
        scheduler="ddim",
        num_inference_steps=25,
        guidance_scale=7.5,
        control_scale=1.9,
        control_start=0.19,
        control_end=1,
        samples=1,
        seed=1234567,
        size=768,
        base64=False,
    ):
        data = {
            "image": toB64(image),
            "prompt": prompt,
            "negative_prompt": negative_prompt,
            "scheduler": scheduler,
            "num_inference_steps": num_inference_steps,
            "guidance_scale": guidance_scale,
            "control_scale": control_scale,
            "control_start": control_start,
            "control_end": control_end,
            "samples": samples,
            "seed": seed,
            "size": size,
            "base64": f"{base64}",
        }
        response = requests.post(self.url, json=data, headers=self.headers)
        if response.status_code == 200:
            print(
                f"Success! You have {response.headers['X-remaining-credits']} credits remaining"
            )
            return Image.open(BytesIO(response.content))
        else:
            raise Exception(f"Error: {response.text}")



import requests
from PIL import Image
from io import BytesIO
import random


class T2I:
    def __init__(self, url, api_key=None):
        self.headers = {"x-api-key": f"{api_key}"}
        self.url = url
        if api_key is None:
            raise Exception("API Key is required")

    def generate(
        self,
        prompt: str,
        negative_prompt: str = "nude, disfigured, blurry",
        samples=1,
        scheduler="dmpp_2m",
        num_inference_steps=25,
        guidance_scale=7,
        seed=None,
        strength=0.75,
    ):
        if not seed:
            seed = random.randint(0, 1000000000)
        data = {
            "prompt": prompt,
            "negative_prompt": negative_prompt,
            "samples": f"{samples}",
            "scheduler": scheduler,
            "img_height": 1024,
            "img_width": 1024,
            "num_inference_steps": f"{num_inference_steps}",
            "guidance_scale": f"{guidance_scale}",
            "seed": f"{seed}",
            "strength": f"{strength}",
        }
        response = requests.post(self.url, json=data, headers=self.headers)
        if response.status_code == 200:
            print(
                f"Success! You have {response.headers['X-remaining-credits']} credits remaining"
            )
            return Image.open(BytesIO(response.content))
        else:
            raise Exception(f"Error: {response.status_code}")



import requests
from PIL import Image
from io import BytesIO


class SD2_1:
    """
    SD2_1 is a class that allows you to generate images from text using the Segmind API.
    The API is available at https://api.segmind.com/v1/sd2.1-txt2img.

    The API accepts the following parameters:

        prompt: str
            Prompt to render, eg. "Stormtrooper giving a lecture"

        negative_prompt: str
            Prompts to exclude, eg. "bad anatomy, bad hands, missing fingers"
            Default: None

        samples: int
            Number of output images
            Default: 1

        scheduler: str
        Type of scheduler.
        Options: ["DDIM", "DPM Multi", "DPM Single", "Euler a", "Euler", "Heun", "DPM2 a Karras", "DPM2 Karras", "LMS", "PNDM", "DDPM", "UniPC"]
        Default: UniPC

        num_inference_steps: int
            Number of denoising steps.
            Default: 20; Max: 50

        guidance_scale: float
            Scale for classifier-free guidance
            Default: 7.5

        seed: int
            Seed for image generation.
            Default: Random

        shape: int
            Image resolution. Options are 512 x 512 or 768 x 768.
            Options: ["512","768"]
            Default: 512
    """

    def __init__(self, api_key=None):
        self.url = "https://api.segmind.com/v1/sd2.1-txt2img"
        self.headers = {"x-api-key": f"{api_key}"}
        if api_key is None:
            raise Exception("API Key is required")

    def generate(
        self,
        prompt,
        negative_prompt="nude, disfigured, blurry",
        samples=1,
        scheduler="DDIM",
        num_inference_steps=25,
        guidance_scale=7.5,
        seed=17123564234,
    ):
        data = {
            "prompt": prompt,
            "negative_prompt": negative_prompt,
            "samples": f"{samples}",
            "scheduler": scheduler,
            "num_inference_steps": f"{num_inference_steps}",
            "guidance_scale": f"{guidance_scale}",
            "seed": f"{seed}",
        }
        response = requests.post(self.url, json=data, headers=self.headers)
        if response.status_code == 200:
            print(
                f"Success! You have {response.headers['X-remaining-credits']} credits remaining"
            )
            return Image.open(BytesIO(response.content))
        else:
            raise Exception(f"Error: {response.status_code}")



import requests
from PIL import Image
from io import BytesIO
from .utils import toB64

class SD1_5:
    """
    This API allows you to generate images from images and inpaint images using the SD v1.5. It is available at https://api.segmind.com/v1/sd1.5-img2img and https://api.segmind.com/v1/sd1.5-inpainting.
    The API accepts a prompt and returns the generated image.

    The API accepts the following parameters:
        prompt: str
            Prompt to render, eg. "Stormtrooper giving a lecture"

        imageUrl: str
            Input reference image URL.

        negative_prompt: str
            Prompts to exclude, eg. "bad anatomy, bad hands, missing fingers"
            Default: None

        samples: int
            Number of output images
            Default: 1

        scheduler: enum
            Type of scheduler.
            Options: ["DDIM", "DPM Multi", "DPM Single", "Euler a", "Euler", "Heun", "DPM2 a Karras", "DPM2 Karras", "LMS", "PNDM", "DDPM"]
            Default: DDIM

        num_inference_steps: int
            Number of denoising steps.
            Default: 20; Max: 50

        guidance_scale: float
            Scale for classifier-free guidance
            Default: 7.5

        seed: int
            Seed for image generation.
            Default: Random

        strength: float
            How much to transform the reference image
            Default: 1; Range: 0 to 1

        maskUrl: str
            Input mask image URL. Only required for sd1.5-inpainting
    """

    def __init__(self, api_key=None):
        self.headers = {"x-api-key": f"{api_key}"}
        if api_key is None:
            raise Exception("API Key is required")

    def generate(
        self,
        prompt: str,
        imageUrl,
        maskUrl=None,
        negative_prompt: str = "nude, disfigured, blurry",
        samples=1,
        scheduler="DDIM",
        num_inference_steps=50,
        guidance_scale=10.5,
        seed=98877465625,
        strength=0.75,
    ):
        data = {
            "prompt": prompt,
            "negative_prompt": negative_prompt,
            "samples": f"{samples}",
            "scheduler": scheduler,
            "num_inference_steps": f"{num_inference_steps}",
            "guidance_scale": f"{guidance_scale}",
            "seed": f"{seed}",
            "strength": f"{strength}",
            "image": toB64(imageUrl),
        }
        if maskUrl:
            data["mask"] = toB64(maskUrl)
            url = "https://api.segmind.com/v1/sd1.5-inpainting"
        else:
            url = "https://api.segmind.com/v1/sd1.5-img2img"
        response = requests.post(url, json=data, headers=self.headers)
        if response.status_code == 200:
            print(
                f"Success! You have {response.headers['X-remaining-credits']} credits remaining"
            )
            return Image.open(BytesIO(response.content))
        else:
            raise Exception(f"Error: {response.status_code}")



from .T2I import T2I


class Juggernaut(T2I):
    def __init__(self, api_key=None):
        super().__init__(
            url="https://api.segmind.com/v1/sd1.5-juggernaut", api_key=api_key
        )

    def generate(
        self,
        prompt: str,
        negative_prompt: str = "(worst quality, low quality, normal quality, lowres, low details, oversaturated, undersaturated, overexposed, underexposed, grayscale, bw, bad photo, bad photography, bad art)++++, (watermark, signature, text font, username, error, logo, words, letters, digits, autograph, trademark, name)+, (blur, blurry, grainy), morbid, ugly, asymmetrical, mutated malformed, mutilated, poorly lit, bad shadow, draft, cropped, out of frame, cut off, censored, jpeg artifacts, out of focus, glitch, duplicate, (airbrushed, cartoon, anime, semi-realistic, cgi, render, blender, digital art, manga, amateur)++, (3D ,3D Game, 3D Game Scene, 3D Character), (bad hands, bad anatomy, bad body, bad face, bad teeth, bad arms, bad legs, deformities)++",
        samples=1,
        scheduler="dpmpp_2m",
        num_inference_steps=25,
        guidance_scale=5,
        seed=None,
        strength=0.75,
    ):
        return super().generate(
            prompt=prompt,
            negative_prompt=negative_prompt,
            samples=samples,
            scheduler=scheduler,
            num_inference_steps=num_inference_steps,
            guidance_scale=guidance_scale,
            seed=seed,
            strength=strength,
        )



from .BackgroundRemoval import BackgroundRemoval
from .Codeformer import Codeformer
from .ESRGAN import ESRGAN
from .SD1_5 import SD1_5
from .SD2_1 import SD2_1
from .Kadinsky import Kadinsky
from .FaceSwap import FaceSwap
from .SAM import SAM
from .ControlNet import ControlNet
from .TinySD import TinySD
from .SDXL import SDXL
from .PortraitSD import PortraitSD
from .SmallSD import SmallSD
from .CyberRealistic import CyberRealistic
from .Paragon import Paragon
from .RealisticVision import RealisticVision
from .Reliberate import Reliberate
from .Revanimated import Revanimated
from .Colorful import Colorful
from .Cartoon import Cartoon
from .EdgeOfRealism import EdgeOfRealism
from .EpicRealism import EpicRealism
from .RPG import RPG
from .SciFi import SciFi
from .Samaritan import Samaritan
from .RCNZ import RCNZ
from .MajicMix import MajicMix
from .ManmaruMix import ManmaruMix
from .Juggernaut import Juggernaut
from .Icbinp import Icbinp
from .FruitFusion import FruitFusion
from .Flat2D import Flat2D
from .FantassifiedIcons import FantassifiedIcons
from .DeepSpaceDiffusion import DeepSpaceDiffusion
from .DreamShaper import DreamShaper
from .DvArch import DvArch
from .CuteRichStyle import CuteRichStyle
from .AllInOnePixel import AllInOnePixel
from .Mix526 import Mix526
from .SDOutpainting import SDOutpainting
from .Word2Img import Word2Img
from .QRGenerator import QRGenerator



import requests
from PIL import Image
from io import BytesIO


class BackgroundRemoval:
    """
    This API allows you to remove the background from an image. It is available at https://api.segmind.com/v1/bg-removal.
    The API accepts a URL of the image to be processed and returns the image with the background removed.

    The API accepts the following parameters:
        imageUrl = str
            the link to the image

    The API returns the following:
        PIL Image with the background removed.

    It also prints the the number of credits remaining in your account.
    """

    def __init__(self, api_key=None):
        self.url = "https://api.segmind.com/v1/bg-removal"
        self.headers = {"x-api-key": f"{api_key}"}
        if api_key is None:
            raise Exception("API Key is required")

    def generate(self, imageUrl):
        data = {"method": "object", "imageUrl": imageUrl}
        response = requests.post(self.url, json=data, headers=self.headers)
        if response.status_code == 200:
            print(f"Success! You have {response.headers['X-remaining-credits']} credits remaining")
            return Image.open(BytesIO(response.content))
        else:
            raise Exception(f"Error: {response.status_code}")



import requests
from PIL import Image
from io import BytesIO
from base64 import b64decode


class Codeformer:
    """
    This API harnesses the power of CodeFormer, a robust face restoration algorithm designed specifically for old photos or AI-generated faces, and is available at https://api.segmind.com/v1/codeformer

    The API accepts a URL of the image to be processed and returns the image with the face restored.

    The API accepts the following parameters:
        imageUrl = str
            the link to the image

        scale = int
            The final upsampling scale of the image

        fidelity = int
            level of fidelity or quality desired for the generated image.
            values between 0 to 1.

        bg = int
            refers to the enhancement of the background present in the image.
            values between 0 to 1.

        face = int
            refers to the enhancement of the face present in the image.
            values between 0 to 1.

        base64 = str
            if the image is in base64 format or not.
            values: "true" or "false"

    The API returns the following:
        PIL Image with the face restored.

    It also prints the the number of credits remaining in your account.
    """

    def __init__(self, api_key=None):
        self.url = "https://api.segmind.com/v1/codeformer"
        self.headers = {"x-api-key": f"{api_key}"}
        if api_key is None:
            raise Exception("API Key is required")

    def generate(self, imageUrl, scale=1, fidelity=0.5, bg=1, face=1, base64="true"):
        data = {
            "scale": scale,
            "fidelity": fidelity,
            "bg": bg,
            "face": face,
            "imageUrl": imageUrl,
            "base64": base64,
        }
        response = requests.post(self.url, json=data, headers=self.headers)
        if response.status_code == 200:
            print(
                f"Success! You have {response.headers['X-remaining-credits']} credits remaining"
            )
            return Image.open(BytesIO(b64decode(response.content[14:])))
        else:
            raise Exception(f"Error: {response.status_code}")



import requests
from PIL import Image
from io import BytesIO


class Kadinsky:
    """
    This API allows you to transform text descriptions into corresponding image representations and is available at https://api.segmind.com/v1/kandinsky2.1-txt2img.

    The API accepts the following parameters:
        prompt: The text description of the image to be generated.
        negative_prompt: The text description of the image to be avoided.
        samples: The number of images to be generated. The default value is 1.
        scheduler: The scheduler to be used for the generation. The default value is DDIM.
        num_inference_steps: The number of inference steps to be used for the generation. The default value is 20.
        guidance_scale: The guidance scale to be used for the generation. The default value is 7.5.
        seed: The seed to be used for the generation. The default value is 1024.
        img_width: The width of the image to be generated. The default value is 512.
        img_height: The height of the image to be generated. The default value is 512.

    The API returns the following:
        The generated image.

    It also prints the number of credits remaining in your account.
    """

    def __init__(self, api_key: str = None):
        self.url = "https://api.segmind.com/v1/kandinsky2.2-txt2img"
        self.headers = {"x-api-key": f"{api_key}"}
        if api_key is None:
            raise Exception("API Key is required")

    def generate(
        self,
        prompt: str,
        negative_prompt: str = "NONE",
        samples=1,
        scheduler="DDIM",
        num_inference_steps=20,
        guidance_scale=7.5,
        seed=1024,
        img_width=512,
        img_height=512,
    ):
        data = {
            "prompt": prompt,
            "negative_prompt": negative_prompt,
            "samples": f"{samples}",
            "scheduler": scheduler,
            "num_inference_steps": f"{num_inference_steps}",
            "guidance_scale": f"{guidance_scale}",
            "seed": f"{seed}",
            "img_width": f"{img_width}",
            "img_height": img_height,
        }
        response = requests.post(self.url, json=data, headers=self.headers)
        if response.status_code == 200:
            print(
                f"Success! You have {response.headers['X-remaining-credits']} credits remaining"
            )
            return Image.open(BytesIO(response.content))
        else:
            raise Exception(f"Error: {response.status_code}")



from .T2I import T2I


class SDXL(T2I):
    def __init__(self, api_key=None):
        super().__init__(
            url="https://api.segmind.com/v1/sdxl1.0-txt2img", api_key=api_key
        )

    def generate(
        self,
        prompt: str,
        negative_prompt: str = "ugly, tiling, poorly drawn hands, poorly drawn feet, poorly drawn face, out of frame, extra limbs, disfigured, deformed, body out of frame, blurry, bad anatomy, blurred, watermark, grainy, signature, cut off, draft",
        samples=1,
        scheduler="dpmmp_sde_ancestral",
        num_inference_steps=25,
        guidance_scale=7,
        seed=None,
        strength=0.75,
    ):
        return super().generate(
            prompt=prompt,
            negative_prompt=negative_prompt,
            samples=samples,
            scheduler=scheduler,
            num_inference_steps=num_inference_steps,
            guidance_scale=guidance_scale,
            seed=seed,
            strength=strength,
        )



import requests
from PIL import Image
from io import BytesIO
from .utils import toB64

class FaceSwap:
    """
    This API allows you to swap faces in images and is available at https://api.segmind.com/v1/sd2.1-faceswapper.

    The API accepts the following parameters:
        imageUrl: The URL of the image to be processed.
        maskUrl: The URL of the mask to be used for the face swap.
        file_type: The file type of the output image. Default is gif.

    The API returns the following:
        PIL Image with the faces swapped.

    It also prints the number of credits remaining in your account.
    """

    def __init__(self, api_key: str = None):
        self.url = "https://api.segmind.com/v1/sd2.1-faceswapper"
        self.headers = {"x-api-key": f"{api_key}"}
        if api_key is None:
            raise Exception("API Key is required")

    def generate(self, imageUrl: str, maskUrl: str, file_type: str = "gif"):
        data = {
            "input_face_image": toB64(imageUrl),
            "target_face_image": toB64(maskUrl),
            "file_type": file_type,
        }
        response = requests.post(self.url, json=data, headers=self.headers)
        if response.status_code == 200:
            print(
                f"Success! You have {response.headers['X-remaining-credits']} credits remaining"
            )
            return Image.open(BytesIO(response.content))
        else:
            raise Exception(f"Error: {response.status_code}")



import requests
from PIL import Image
from io import BytesIO


class ControlNet:
    """
    This API allows you to generate images using various images using ControlNet and is available at https://api.segmind.com/v1/sd1.5-controlnet-canny, https://api.segmind.com/v1/sd1.5-controlnet-depth, https://api.segmind.com/v1/sd1.5-controlnet-openpose, https://api.segmind.com/v1/sd1.5-controlnet-scribble, https://api.segmind.com/v1/sd1.5-controlnet-softedge.

    The API accepts the following parameters:

    prompt: str
        Prompt to render, eg. "Stormtrooper giving a lecture"

    imageUrl: str
        Input image URL.

    option: str
        Type of ControlNet.
        Options: ["Canny", "Depth", "OpenPose", "Scribble", "SoftEdge"]
    negative_prompt: str
        Prompts to exclude, eg. "bad anatomy, bad hands, missing fingers"
        Default: None

    samples: int
        Number of output images
        Default: 1

    scheduler: str
        Type of scheduler.
        Options: ["DDIM", "DPM Multi", "DPM Single", "Euler a", "Euler", "Heun", "DPM2 a Karras", "DPM2 Karras", "LMS", "PNDM", "DDPM", "UniPC"]
        Default: UniPC

    num_inference_steps: int
        Number of denoising steps.
        Default: 20; Max: 50

    guidance_scale: float
        Scale for classifier-free guidance
        Default: 7.5

    seed: int
        Seed for image generation.
        Default: Random

    strength: float
        Controlnet conditioning, closeness to the original image.
        Default: 1; Range: 0 to 1

    The API returns the following:
        The generated image.

    It also prints the number of credits remaining in your account.
    """

    def __init__(self, api_key=None):
        self.headers = {"x-api-key": f"{api_key}"}
        if api_key is None:
            raise Exception("API Key is required")

    def generate(
        self,
        prompt: str,
        imageUrl,
        option,
        negative_prompt: str = "nude, disfigured, cartoon, blurry",
        samples=1,
        scheduler="UniPC",
        num_inference_steps=50,
        guidance_scale=10.5,
        seed=98877465625,
        strength=0.75,
    ):
        data = {
            "prompt": prompt,
            "negative_prompt": negative_prompt,
            "samples": f"{samples}",
            "scheduler": scheduler,
            "num_inference_steps": f"{num_inference_steps}",
            "guidance_scale": f"{guidance_scale}",
            "seed": f"{seed}",
            "strength": f"{strength}",
            "imageUrl": imageUrl,
        }
        option = option.lower()
        if option == "canny":
            url = "https://api.segmind.com/v1/sd1.5-controlnet-canny"
        elif option == "depth":
            url = "https://api.segmind.com/v1/sd1.5-controlnet-depth"
        elif option == "openpose":
            url = "https://api.segmind.com/v1/sd1.5-controlnet-openpose"
        elif option == "scribble":
            url = "https://api.segmind.com/v1/sd1.5-controlnet-scribble"
        elif option == "softedge":
            url = "https://api.segmind.com/v1/sd1.5-controlnet-softedge"
        else:
            raise Exception("Invalid option")

        response = requests.post(url, json=data, headers=self.headers)
        if response.status_code == 200:
            print(
                f"Success! You have {response.headers['X-remaining-credits']} credits remaining"
            )
            return Image.open(BytesIO(response.content))
        else:
            raise Exception(f"Error: {response.status_code}")



from setuptools import setup

# read the contents of your README file
from pathlib import Path
this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text()

setup(name='segmind',
      version='0.2.1',
      description='Package for Using Segmind APIs in Python',
      url='https://docs.segmind.com/apis',
      author='Yatharth Gupta',
      license='MIT',
      packages=['segmind'],
      author_email='yatharthg@segmind.com',
      install_requires=[
          'pillow',
      ],
      long_description=long_description,
      long_description_content_type='text/markdown',
      zip_safe=False)


from .T2I import T2I


class Samaritan(T2I):
    def __init__(self, api_key=None):
        super().__init__(
            url="https://api.segmind.com/v1/sd1.5-samaritan_3d", api_key=api_key
        )

    def generate(
        self,
        prompt: str,
        negative_prompt: str = "EasyNegativeV2 ng_deepnegative_v1_75t greyscale (worst quality, low quality)",
        samples=1,
        scheduler="euler_a",
        num_inference_steps=20,
        guidance_scale=7.5,
        seed=None,
        strength=0.75,
    ):
        return super().generate(
            prompt=prompt,
            negative_prompt=negative_prompt,
            samples=samples,
            scheduler=scheduler,
            num_inference_steps=num_inference_steps,
            guidance_scale=guidance_scale,
            seed=seed,
            strength=strength,
        )



import requests
from PIL import Image
from io import BytesIO
from .utils import toB64


class SDOutpainting:
    """
    This API allows you to outpaint images. It is available at https://api.segmind.com/v1/sd1.5-outpaint.
    The API accepts a URL of the image to be processed and returns the "uncropped" image.

    The API accepts the following parameters:
        image = str
            the link to the image
        prompt = str
            Prompts to render
        negative_prompt = str
            prompts to exclude
        scheduler = str
            type of scheduler
        num_inference_steps = int
            Number of denoising steps.
        img_width = int
            Desired result image width
        img_height = int
            Desired result Image Height
        scale = int
            Scale for classifier-free guidance
        strength = int
            Strength controls how much the images can vary
        offset_x = int
            Offset of the init image on the horizontal axis from the left.
        offset_y = int
            Offset of the init image on the vertical axis from the top.
        guidance_scale = float
            Scale for classifier-free guidance
        mask_expand = int
            Mask Expansion in pixels uniformly in all four sides, this sometimes helps the model to achieve more seamless results.
        seed = int
            Seed for image generation. The default value is 1234567.

    The API returns the following:
        PIL Image of the Outpaint.

    It also prints the the number of credits remaining in your account.
    """

    def __init__(self, api_key=None):
        self.url = "https://api.segmind.com/v1/sd1.5-outpaint"
        self.headers = {"x-api-key": f"{api_key}"}
        if api_key is None:
            raise Exception("API Key is required")

    def generate(
        self,
        image,
        prompt,
        negative_prompt="None",
        scheduler="DDIM",
        num_inference_steps=25,
        img_width=1024,
        img_height=1024,
        scale=1,
        strength=1,
        offset_x=256,
        offset_y=256,
        guidance_scale=7.5,
        mask_expand=8,
        seed=1234567,
    ):
        data = {
            "image": toB64(image),
            "prompt": prompt,
            "negative_prompt": negative_prompt,
            "scheduler": scheduler,
            "num_inference_steps": num_inference_steps,
            "img_width": img_width,
            "img_height": img_height,
            "scale": scale,
            "strength": strength,
            "offset_x": offset_x,
            "offset_y": offset_y,
            "guidance_scale": guidance_scale,
            "mask_expand": mask_expand,
            "seed": seed,
        }
        response = requests.post(self.url, json=data, headers=self.headers)
        if response.status_code == 200:
            print(
                f"Success! You have {response.headers['X-remaining-credits']} credits remaining"
            )
            return Image.open(BytesIO(response.content))
        else:
            raise Exception(f"Error: {response.status_code}")
